@@ -33,7 +33,7 @@ __END__
 
 =head1 NAME
 
-Mojolicious::Plugin::Charset - Charset Plugin
+Mojolicious::Plugin::Charset - Charset plugin
 
 =head1 SYNOPSIS
 
@@ -50,6 +50,8 @@ and encoding on all layers of L<Mojolicious>.
 
 =head1 OPTIONS
 
+L<Mojolicious::Plugin::Charset> supports the following options.
+
 =head2 C<charset>
 
   # Mojolicious::Lite
