@@ -661,6 +661,8 @@ Reset user agent session.
 
   $t = $t->send_message_ok('hello');
   $t = $t->send_message_ok('hello', 'sent successfully');
+  $t = $t->send_message_ok([$bytes]);
+  $t = $t->send_message_ok([$bytes], 'sent successfully');
 
 Send C<WebSocket> message.
 Note that this method is EXPERIMENTAL and might change without warning!
